# Description

Network Protocol Data Exfiltration Project - A modular approach for data exfiltration

# Installation

`pip install npdep_common`

# Usage

It does not have any direct functionality. It does only provide common types and capabilites to NPDEP.